<!DOCTYPE TS><TS>
<context>
    <name>@default</name>
    <message>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <source>Autoaway</source>
        <translation>Autoaway</translation>
    </message>
    <message>
        <source>Check idle every</source>
        <translation>Controlla  Iddle ogni</translation>
    </message>
    <message>
        <source>Enable autoaway</source>
        <translation>Occupato automatico</translation>
    </message>
    <message>
        <source>Set status to away after</source>
        <translation>Metti status Occupato dopo</translation>
    </message>
    <message>
        <source>Enable autoinvisible</source>
        <translation>Attiva autoinvisibile</translation>
    </message>
    <message>
        <source>Set status to invisible after</source>
        <translation>Metti status invisibile dopo</translation>
    </message>
    <message>
        <source>Enable autodisconnect</source>
        <translation>Attiva autosconessione</translation>
    </message>
    <message>
        <source>Disconnect after</source>
        <translation>Sconnetti dopo</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Descrizione</translation>
    </message>
    <message>
        <source>Don&apos;t change</source>
        <translation>Non cambiare descrizione</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>Cambia</translation>
    </message>
    <message>
        <source>Add in front</source>
        <translation>Aggiungi all&apos;inizio</translation>
    </message>
    <message>
        <source>Add at the back</source>
        <translation>Agiungi alla fine</translation>
    </message>
    <message>
        <source>New description</source>
        <translation>Nuovo descrizione</translation>
    </message>
    <message>
        <source>Autorefresh status</source>
        <translation>Rinfrescare automatico</translation>
    </message>
    <message>
        <source>Parse AutoStatus</source>
        <translation>Parse status automatico</translation>
    </message>
</context>
<context>
    <name>AutoAway</name>
    <message>
        <source>Don&apos;t refresh</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
